//Bibliotheken für den BME680 Sensor
#include <SPI.h>
#include <Adafruit_Sensor.h>
#include "Adafruit_BME680.h"

/**
  Konfiguration des Sensors am ESP8266
  Da der verwendete ESP8266 von Ideaspark bereits über ein I2C OLED Display verfügt welches über D5 & D6 
  angeschlossen ist, müssen wir andere Pins für die SPI Kommunikation verwenden!
**/
#define BME_SCK D1
#define BME_MISO D2
#define BME_MOSI D7
#define BME_CS D8

#define SEALEVELPRESSURE_HPA (1013.25)

//erzeugen eines Objektes vom Typ Adafruit_BME680 mit der SPI Konfiguration
Adafruit_BME680 bme(BME_CS, BME_MOSI, BME_MISO, BME_SCK);


void setup() {
  //starten der seriellen Kommunikation mit 9600 Baud.
  Serial.begin(9600);
  while (!Serial){
    //Warten bis die serielle Schnittstelle bereit steht.
  }
  
  //starten der Kommunikation mit dem Sensor.
  //Wenn dieses nicht funktioniert, soll eine Fehlermeldung ausgegeben
  //und eine Endlosschleife gestartet werden.
  if (!bme.begin()) {
    Serial.println("Es konnte kein Sensor vom Typ BME680 gefunden werden!");
    Serial.println("Prüfen Sie die Verkabelung / Konfiguration!");
    while (1)
      ;
  }

  //Setup der Sensordaten (wurde vom Beispiel belassen)
  bme.setTemperatureOversampling(BME680_OS_8X);
  bme.setHumidityOversampling(BME680_OS_2X);
  bme.setPressureOversampling(BME680_OS_4X);
  bme.setIIRFilterSize(BME680_FILTER_SIZE_3);
  bme.setGasHeater(320, 150);  // 320*C for 150 ms
}

void loop() {
  //anfordern der aktuellen Sensordaten
  if (!bme.performReading()) {
    Serial.println("Fehler beim lesen der Sensordaten!");
    return;
  }

  //Funktion String(sensorwert, 2) kürzt den Wert auf zwei Stellen nach dem Komma.

  //auslesen der Temperatur
  String temp = "Temperatur: ";  
  temp = temp + String(bme.temperature, 2);
  temp = temp + " *C";

  //auslesen des Luftdrucks
  String luftdruck = "Luftdruck: ";
  luftdruck = luftdruck + String(bme.pressure / 100.0, 2);
  luftdruck = luftdruck + " hPa";

  //auslesen der rel. Luftfeuchtigkeit
  String relLuftfeuchtigkeit = "rel. Luftfeuchtigkeit: ";
  relLuftfeuchtigkeit = relLuftfeuchtigkeit + String(bme.humidity, 2);
  relLuftfeuchtigkeit = relLuftfeuchtigkeit + "%";

  //auslesen der ungefähren Höhe
  String hoehe = "ungef. Höhe: ";
  hoehe = hoehe + String(bme.readAltitude(SEALEVELPRESSURE_HPA), 2);
  hoehe = hoehe + " m";

  //berechnen der Luftqualität
  String luftqualitaet = "Luftqualität: ";
  luftqualitaet = luftqualitaet + String(bme.gas_resistance / 1000.0,2);
  luftqualitaet = luftqualitaet + " kOhm";

  //ein Trenner
  Serial.println("**************************");
  
  //Ausgeben der ermittelten Daten auf der seriellen Schnittstelle
  Serial.println(temp);
  Serial.println(luftdruck);
  Serial.println(relLuftfeuchtigkeit);
  Serial.println(hoehe);
  Serial.println(luftqualitaet);

  //eine kleine Pause von 2 Sekunden
  delay(2000);
}